Device

Struct Device 

pub struct Device { /* private fields */ }

Implementations

Source

impl Device

pub fn open<P>(path: P) -> Result<Self, Error>
where P: AsRef<Path>,

pub fn id(&self) -> Result<DeviceId, Error>

pub fn name(&self) -> Result<String, Error>

pub fn physical_location(&self) -> Result<String, Error>

pub fn read( &self, timeout: Option<Duration>, ) -> Result<Option<InputEvent>, Error>

pub fn get_raw_abs_info(&self, axis: AbsoluteAxis) -> Result<RawAbsInfo, Error>

pub fn event_bits_of_kind<T>( &self, ) -> Result<impl Iterator<Item = T> + FusedIterator, Error>
where T: EventCode,

pub fn absolute_axis_event_bits( &self, ) -> Result<impl Iterator<Item = AbsoluteAxisBit> + FusedIterator, Error>

pub fn event_bits( &self, ) -> Result<impl Iterator<Item = EventBit> + FusedIterator, Error>

pub fn upload_force_feedback_effect( &self, effect: impl Into<RawForceFeedbackEffect>, ) -> Result<ForceFeedbackEffectId, Error>

pub fn erase_force_feedback_effect( &self, id: ForceFeedbackEffectId, ) -> Result<(), Error>

pub fn enable_force_feedback_effect( &self, effect_id: ForceFeedbackEffectId, cycle_count: i32, ) -> Result<(), Error>

pub fn disable_force_feedback_effect( &self, effect_id: ForceFeedbackEffectId, ) -> Result<(), Error>

pub fn grab(&self) -> Result<(), Error>

Grabs the device for exclusive access.

No one else will receive any events from it.

pub fn release(&self) -> Result<(), Error>

Releases the device from exclusive access.

pub fn emit<T>(&self, body: T) -> Result<(), Error>

Emits a given event just as if it was sent by the device itself.

Makes sense only when the device is not grabbed for exclusive access.